# CRA
[![Documentation Status](https://readthedocs.org/projects/cra/badge/?version=latest)](https://cra.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/github/license/Shadow15510/cra?color=green)](https://github.com/Shadow15510/cra/blob/master/LICENSE)
[![Build Status](https://github.com/Shadow15510/cra/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Shadow15510/cra/actions/workflows/python-publish.yml)
[![PyPi](https://img.shields.io/pypi/v/cra)](https://pypi.org/project/cra/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Description
This small Python package allows to simply draw upper air sounding on a Skew-T diagramm using ``metpy`` library.

## Installation
A PyPi package is available. You can check the [PyPi page](https://pypi.org/project/cra/) or simply run `pip install cra` in you terminal.

This package need have some dependancies:
- `metpy`;
- `numpy`;
- `matplotlib`;
- `pandas`.

## Licence
This code is provided under the GNU General Public Licence v3.0+ (GPLv3+).

Please refer to LICENCE file for further information. 
